==> sghi_core-0.3.73.tar.gz: test/app_wrapper/app_wrapper_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/app_wrapper/app_config.dart';
import 'package:sghi_core/app_wrapper/app_wrapper.dart';
import 'package:sghi_core/app_wrapper/app_wrapper_base.dart';
import 'package:sghi_core/app_wrapper/device_capabilities.dart';
import 'package:sghi_core/app_wrapper/enums.dart';
import 'package:sghi_core/flutter_graphql_client/flutter_graphql_client.dart';

import 'mocks.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();

  final GraphQlClient graphClient = GraphQlClient('token', 'url');

  // Adjusted to create a single AppConfig instance
  final AppConfig appContext = AppConfig(
      variant: AppVariant.BEWELL,
      environment: AppEnvironment.TEST); // Adjust with real values

  testWidgets('should test AppWrapper', (WidgetTester tester) async {
    await tester.pumpWidget(
      MaterialApp(
        home: AppWrapper(
          appName: 'test',
          graphQLClient: graphClient,
          communitiesClient: graphClient,
          // Pass the single AppConfig instance directly
          appContext: appContext,
          child: Container(),
        ),
      ),
    );

    final Finder silAppWrapperKey = find.byKey(const Key('sil_app_wrapper'));
    expect(silAppWrapperKey, findsOneWidget);
  });

  group('AppWrapperBase', () {
    testWidgets(
      'should check for AppWrapperBase on widget tree and test for valid deviceCapabilities',
      (WidgetTester tester) async {
        late IDeviceCapabilities deviceCapabilities;

        await tester.pumpWidget(MaterialApp(
          home: AppWrapperBase(
            appName: 'test',
            graphQLClient: graphClient,
            communitiesClient: graphClient,
            // Pass the single AppConfig instance directly
            appContext: appContext,
            deviceCapabilities: MockDeviceCapabilities(),
            child: Builder(builder: (BuildContext context) {
              deviceCapabilities =
                  AppWrapperBase.of(context)!.deviceCapabilities;
              return Container();
            }),
          ),
        ));

        expect(find.byType(AppWrapperBase), findsOneWidget);
        expect(deviceCapabilities, isA<IDeviceCapabilities>());
      },
    );

    testWidgets('should check that AppWrapperBase notifies dependant',
        (WidgetTester tester) async {
      final List<AppWrapperBase> log = <AppWrapperBase>[];

      final Builder builder = Builder(builder: (BuildContext context) {
        log.add(context.dependOnInheritedWidgetOfExactType<AppWrapperBase>()!);
        return Container();
      });

      // The AppWrapperBase initialization does not change here, but ensure appContexts parameter is updated
      // if your implementation of AppWrapperBase now requires a single AppConfig instance.
      // The example assumes no change in the signature for AppWrapperBase, which might not be accurate.
      // Update according to your actual class definitions.

      final AppWrapperBase first = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        communitiesClient: graphClient,
        // Update these initializations as per the new AppWrapperBase constructor
        appContext: appContext,
        shouldNotify: false,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: first));

      final AppWrapperBase second = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        // Same here for appContext
        appContext: appContext,
        shouldNotify: false,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: second));

      expect(log, equals(<AppWrapperBase>[first]));

      final AppWrapperBase third = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        // And here as well
        appContext: appContext,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: third));

      expect(log, equals(<AppWrapperBase>[first, third]));
    });
  });
}

==> sghi_core-0.3.74.tar.gz: test/app_wrapper/app_wrapper_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/app_wrapper/app_config.dart';
import 'package:sghi_core/app_wrapper/app_wrapper.dart';
import 'package:sghi_core/app_wrapper/app_wrapper_base.dart';
import 'package:sghi_core/app_wrapper/device_capabilities.dart';
import 'package:sghi_core/app_wrapper/enums.dart';
import 'package:sghi_core/flutter_graphql_client/flutter_graphql_client.dart';

import 'mocks.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();

  final GraphQlClient graphClient = GraphQlClient('token', 'url');

  // Adjusted to create a single AppConfig instance
  final AppConfig appConfig = AppConfig(
      variant: AppVariant.BEWELL,
      environment: AppEnvironment.TEST); // Adjust with real values

  testWidgets('should test AppWrapper', (WidgetTester tester) async {
    await tester.pumpWidget(
      MaterialApp(
        home: AppWrapper(
          appName: 'test',
          graphQLClient: graphClient,
          communitiesClient: graphClient,
          // Pass the single AppConfig instance directly
          appConfig: appConfig,
          child: Container(),
        ),
      ),
    );

    final Finder silAppWrapperKey = find.byKey(const Key('sil_app_wrapper'));
    expect(silAppWrapperKey, findsOneWidget);
  });

  group('AppWrapperBase', () {
    testWidgets(
      'should check for AppWrapperBase on widget tree and test for valid deviceCapabilities',
      (WidgetTester tester) async {
        late IDeviceCapabilities deviceCapabilities;

        await tester.pumpWidget(MaterialApp(
          home: AppWrapperBase(
            appName: 'test',
            graphQLClient: graphClient,
            communitiesClient: graphClient,
            // Pass the single AppConfig instance directly
            appConfig: appConfig,
            deviceCapabilities: MockDeviceCapabilities(),
            child: Builder(builder: (BuildContext context) {
              deviceCapabilities =
                  AppWrapperBase.of(context)!.deviceCapabilities;
              return Container();
            }),
          ),
        ));

        expect(find.byType(AppWrapperBase), findsOneWidget);
        expect(deviceCapabilities, isA<IDeviceCapabilities>());
      },
    );

    testWidgets('should check that AppWrapperBase notifies dependant',
        (WidgetTester tester) async {
      final List<AppWrapperBase> log = <AppWrapperBase>[];

      final Builder builder = Builder(builder: (BuildContext context) {
        log.add(context.dependOnInheritedWidgetOfExactType<AppWrapperBase>()!);
        return Container();
      });

      // The AppWrapperBase initialization does not change here, but ensure appConfig parameter is updated
      // if your implementation of AppWrapperBase now requires a single AppConfig instance.
      // The example assumes no change in the signature for AppWrapperBase, which might not be accurate.
      // Update according to your actual class definitions.

      final AppWrapperBase first = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        communitiesClient: graphClient,
        // Update these initializations as per the new AppWrapperBase constructor
        appConfig: appConfig,
        shouldNotify: false,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: first));

      final AppWrapperBase second = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        // Same here for appConfig
        appConfig: appConfig,
        shouldNotify: false,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: second));

      expect(log, equals(<AppWrapperBase>[first]));

      final AppWrapperBase third = AppWrapperBase(
        appName: 'test',
        graphQLClient: graphClient,
        // And here as well
        appConfig: appConfig,
        deviceCapabilities: MockDeviceCapabilities(),
        child: builder,
      );
      await tester.pumpWidget(MaterialApp(home: third));

      expect(log, equals(<AppWrapperBase>[first, third]));
    });
  });
}
